#
# spec file for package python3-pymongo
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pymongo
Version:        3.0.3
Release:        7.1
Url:            http://github.com/mongodb/mongo-python-driver
Summary:        Python driver for MongoDB
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/p/pymongo/pymongo-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-devel
BuildRequires:  python3-distribute
#BuildRequires:  python-nose
Suggests:       mongodb
#currently mongodb is available only for little-endian CPU
ExclusiveArch:  %{ix86} x86_64

%description
The PyMongo distribution contains tools for interacting with MongoDB
database from Python.  The bson package is an implementation of
the BSON format for Python. The pymongo package is a native Python
driver for MongoDB. The gridfs package is a gridfs
implementation on top of pymongo.

%prep
%setup -q -n pymongo-%{version}

%build
2to3 .
CFLAGS="%{optflags}" python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

#%%check
#python setup.py test

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{python3_sitearch}/*

%changelog
* Mon Jul 13 2015 arun@gmx.de
- update to version 3.0.3:
  * Error in changelog guidance for Python 3 (find timeout parameter)
  * Unable to specify ssl_match_hostname option using URI style
    connection string
  * Undocumented regression in Collection.find - projection tuple no
    longer allowed
* Mon May 25 2015 arun@gmx.de
- update to version 3.0.2:
  * Auth can fail while connecting to replset with recovering members
  * ReadPreference.NEAREST can route operations to arbiters in PyMongo
    3.0
  * ReadPreference instances aren't copyable
* Fri Apr 24 2015 arun@gmx.de
- update to version 3.0.1:
  * OperationFailure iterating cursor with multiple mongoses
  * GridFS.delete does not remove all chunks in PyMongo 3
  * AssertionError: Result batch started from 101, expected 0
* Wed Apr  8 2015 arun@gmx.de
- update to version 3.0:
  * A unified client class. MongoClient is the one and only client
    class for connecting to a standalone mongod, replica set, or
    sharded cluster. Migrating from a standalone, to a replica set, to
    a sharded cluster can be accomplished with only a simple URI
    change.
  * MongoClient is much more responsive to configuration changes in
    your MongoDB deployment. All connected servers are monitored in a
    non-blocking manner. Slow to respond or down servers no longer
    block server discovery, reducing application startup time and time
    to respond to new or reconfigured servers and replica set
    failovers.
  * A unified CRUD API. All official MongoDB drivers now implement a
    standard CRUD API allowing polyglot developers to move from
    language to language with ease.
  * Single source support for Python 2.x and 3.x. PyMongo no longer
    relies on 2to3 to support Python 3.
  * A rewritten pure Python BSON implementation, improving performance
    with pypy and cpython deployments without support for C
    extensions.
  * Better support for greenlet based async frameworks including
    eventlet.
  * Immutable client, database, and collection classes, avoiding a
    host of thread safety issues in client applications.
  * Many more changes, see https://github.com/mongodb/mongo-python-driver/blob/master/doc/changelog.rst
    for details
* Sat Jan 31 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove ifdef for opensuse version < 1130
- update to version 2.8:
  * Version 2.8 is a major release that provides full support for
    MongoDB 3.0 and fixes a number of bugs.
  * Support for the SCRAM-SHA-1 authentication mechanism (new in
    MongoDB 3.0).
  * JSON decoder support for the new $numberLong and $undefined types.
  * JSON decoder support for the $date type as an ISO-8601 string.
  * Support passing an index name to
    :meth:`~pymongo.cursor.Cursor.hint`.
  * The :meth:`~pymongo.cursor.Cursor.count` method will use a hint if
    one has been provided through :meth:`~pymongo.cursor.Cursor.hint`.
  * A new socketKeepAlive option for the connection pool.
  * New generator based BSON decode functions,
    :func:`~bson.decode_iter` and :func:`~bson.decode_file_iter`.
  * Internal changes to support alternative storage engines like
    wiredtiger.
* Thu Dec 11 2014 arun@gmx.de
- specfile: update copyright year
- update to version 2.7.2:
  * PyMongo 2.7 is a major release with a large number of new features and bug
    fixes. Highlights include:
  - Full support for MongoDB 2.6.
  - A new :doc:"bulk write operations API </examples/bulk>".
  - Support for server side query timeouts using
    :meth:"~pymongo.cursor.Cursor.max_time_ms".
  - Support for writing :meth:"~pymongo.collection.Collection.aggregate"
    output to a collection.
  - A new :meth:"~pymongo.collection.Collection.parallel_scan" helper.
  - :class:"~pymongo.errors.OperationFailure" and its subclasses now include
    a :attr:"~pymongo.errors.OperationFailure.details" attribute with complete
    error details from the server.
  - A new GridFS :meth:"~gridfs.GridFS.find" method that returns a
    :class:"~gridfs.grid_file.GridOutCursor".
  - Greatly improved :doc:"support for mod_wsgi </examples/mod_wsgi>" when using
    PyMongo's C extensions. Read "Jesse's blog post
    <http://emptysqua.re/blog/python-c-extensions-and-mod-wsgi/>" for details.
  - Improved C extension support for ARM little endian.
  * Breaking changes
  - Version 2.7 drops support for replica sets running MongoDB versions older
    than 1.6.2.
  * Issues Resolved
  - See the "PyMongo 2.7 release notes in JIRA" for the list of resolved issues
    in this release.
- changes from version 2.6.3:
  * Version 2.6.3 fixes issues reported since the release of 2.6.2, most
    importantly a semaphore leak when a connection to the server fails.
  * Issues Resolved
  - See the "PyMongo 2.6.3 release notes in JIRA" for the list of resolved issues
    in this release.
- changes from version 2.6.2:
  * Version 2.6.2 fixes a :exc:"TypeError" problem when max_pool_size=None
    is used in Python 3.
  * Issues Resolved
  - See the "PyMongo 2.6.2 release notes in JIRA" for the list of resolved issues
    in this release.
- changes from version 2.6.1:
  * Version 2.6.1 fixes a reference leak in
    the :meth:"~pymongo.collection.Collection.insert" method.
  * Issues Resolved
  - See the "PyMongo 2.6.1 release notes in JIRA" for the list of resolved issues
    in this release.
- changes from version 2.6:
  * Version 2.6 includes some frequently requested improvements and adds
    support for some early MongoDB 2.6 features.
    Special thanks go to Justin Patrin for his work on the connection pool
    in this release.
  * Important new features:
  - The "max_pool_size" option for :class:"~pymongo.mongo_client.MongoClient"
    and :class:"~pymongo.mongo_replica_set_client.MongoReplicaSetClient" now
    actually caps the number of sockets the pool will open concurrently.
    Once the pool has reached :attr:"~pymongo.mongo_client.MongoClient.max_pool_size"
    operations will block waiting for a socket to become available. If
    "waitQueueTimeoutMS" is set, an operation that blocks waiting for a socket
    will raise :exc:"~pymongo.errors.ConnectionFailure" after the timeout. By
    default "waitQueueTimeoutMS" is not set.
    See :ref:"connection-pooling" for more information.
  - The :meth:"~pymongo.collection.Collection.insert" method automatically splits
    large batches of documents into multiple insert messages based on
    :attr:"~pymongo.mongo_client.MongoClient.max_message_size"
  - Support for the exhaust cursor flag.
    See :meth:"~pymongo.collection.Collection.find" for details and caveats.
  - Support for the PLAIN and MONGODB-X509 authentication mechanisms.
    See :doc:"the authentication docs </examples/authentication>" for more
    information.
  - Support aggregation output as a :class:"~pymongo.cursor.Cursor". See
    :meth:"~pymongo.collection.Collection.aggregate" for details.
  * warning: SIGNIFICANT BEHAVIOR CHANGE in 2.6. Previously, "max_pool_size"
    would limit only the idle sockets the pool would hold onto, not the
    number of open sockets. The default has also changed, from 10 to 100.
    If you pass a value for "max_pool_size" make sure it is large enough for
    the expected load. (Sockets are only opened when needed, so there is no cost
    to having a "max_pool_size" larger than necessary. Err towards a larger
    value.) If your application accepts the default, continue to do so.
    See :ref:"connection-pooling" for more information.
  * Issues Resolved
  - See the "PyMongo 2.6 release notes in JIRA" for the list of resolved issues
    in this release.
* Tue Jun  4 2013 mlin@suse.com
- Update to version 2.5.2
  * Version 2.5.2 fixes a NULL pointer dereference issue when decoding
    an invalid :class:`~bson.dbref.DBRef`(bnc#822798, CVE-2013-2132).
    See release notes in JIRA:
    https://jira.mongodb.org/browse/PYTHON/fixforversion/12581 for details.
* Tue Jun  4 2013 mlin@suse.com
- Update to version 2.5.1
  * Version 2.5.1 is a minor release that fixes issues discovered after the
    release of 2.5. Most importantly, this release addresses some race
    conditions in replica set monitoring. See release notes in JIRA:
    https://jira.mongodb.org/browse/PYTHON/fixforversion/12484 for details.
* Wed Apr  3 2013 dvaleev@suse.com
- Set Exclusive arch for LittleEndian machines. mongodb is not
  BigEndian compatible.
* Wed Mar 27 2013 mlin@suse.com
- Update to version 2.5
  * https://jira.mongodb.org/secure/ReleaseNote.jspa?projectId=10004&version=11981
    for details
* Wed Dec 12 2012 mlin@suse.com
- Update to version 2.4.1
  * See https://jira.mongodb.org/secure/ReleaseNote.jspa?projectId=10004&version=12286
    for details
* Wed Dec 12 2012 mlin@suse.com
- Update to version 2.4
  * See https://jira.mongodb.org/secure/ReleaseNote.jspa?projectId=10004&version=11485
    for details
* Wed Sep 26 2012 jzheng@suse.com
- change to use python3
* Mon Sep 24 2012 i@marguerite.su
- Update to version 2.3
  * fixes see https://jira.mongodb.org/browse/PYTHON/fixforversion/11146
  * Support for expanded read preferences including directing
    reads to tagged servers - See Secondary Reads for more
    information.
  * Support for mongos failover - See High Availability and
    mongos for more information.
  * A new aggregate() method to support MongoDB’s new
    aggregation framework.
  * Support for legacy Java and C# byte order when encoding
    and decoding UUIDs.
  * Support for connecting directly to an arbiter.
* Tue Mar 27 2012 saschpe@suse.de
- Change requires on mongodb to suggests, a weak dependency is better
* Tue Feb 28 2012 saschpe@suse.de
- Update to version 2.1.1
  * See https://jira.mongodb.org/browse/PYTHON/fixforversion/11081
    for details
- Require mongodb
* Sat Mar 26 2011 alexandre@exatati.com.br
- Initial package (1.9) for openSUSE.
